# Python client and module for Lacus

Use this module to interact with a [Lacus](https://github.com/ail-project/lacus) instance.

## Installation

```bash
pip install pylacus
```

## Usage

### Command line

You can use the `lacus` command:

```bash
```

### Library

See [API Reference]()
